Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1875)

Unified Diff: content/public/browser/navigation_controller.h

Issue 10704048: [RDS] Reloads a page using the original request URL (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Adding unit test & removing public function Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/navigation_controller.h
diff --git a/content/public/browser/navigation_controller.h b/content/public/browser/navigation_controller.h
index 28d20d30b73a1ba48d4efeda07103c7f585fb631..e546ae5e2684b06c01d80ca7fc0e1e909969e67d 100644
--- a/content/public/browser/navigation_controller.h
+++ b/content/public/browser/navigation_controller.h
@@ -32,9 +32,10 @@ struct Referrer;
class NavigationController {
public:
enum ReloadType {
- NO_RELOAD, // Normal load.
- RELOAD, // Normal (cache-validating) reload.
- RELOAD_IGNORING_CACHE // Reload bypassing the cache, aka shift-reload.
+ NO_RELOAD, // Normal load.
+ RELOAD, // Normal (cache-validating) reload.
+ RELOAD_IGNORING_CACHE, // Reload bypassing the cache (shift-reload).
+ RELOAD_ORIGINAL_REQUEST_URL // Reload using the original request URL.
};
// Creates a navigation entry and translates the virtual url to a real one.

Powered by Google App Engine
This is Rietveld 408576698